@@ -59,7 +59,6 @@
 #include <libnautilus-private/nautilus-tree-view-drag-dest.h>
 #include <libnautilus-private/nautilus-view-factory.h>
 #include <libnautilus-private/nautilus-clipboard.h>
-#include <libnautilus-private/nautilus-cell-renderer-pixbuf-emblem.h>
 #include <libnautilus-private/nautilus-cell-renderer-text-ellipsized.h>
 
 struct FMListViewDetails {
@@ -131,7 +130,7 @@ struct SelectionForeachData {
 #define WAIT_FOR_RENAME_ON_ACTIVATE 200
 
 static int                      click_policy_auto_value;
-static char *              	default_sort_order_auto_value;
+static NautilusFileSortType     default_sort_order_auto_value;
 static gboolean			default_sort_reversed_auto_value;
 static NautilusZoomLevel        default_zoom_level_auto_value;
 static char **                  default_visible_columns_auto_value;
@@ -171,15 +170,27 @@ static const char * default_trash_columns_order[] = {
 /* for EEL_CALL_PARENT */
 #define parent_class fm_list_view_parent_class
 
+
 static const gchar*
 get_default_sort_order (NautilusFile *file, gboolean *reversed)
 {
 	const gchar *retval;
+	const char *attributes[] = {
+		"name", /* is really "manually" which doesn't apply to lists */
+		"name",
+		"uri",
+		"size",
+		"type",
+		"date_modified",
+		"date_accessed",
+		"trashed_on",
+		NULL
+	};
 
 	retval = nautilus_file_get_default_sort_attribute (file, reversed);
 
 	if (retval == NULL) {
-		retval = default_sort_order_auto_value;
+		retval = attributes[default_sort_order_auto_value];
 		*reversed = default_sort_reversed_auto_value;
 	}
 
@@ -626,8 +637,8 @@ button_press_callback (GtkWidget *widget, GdkEventButton *event, gpointer callba
 		(FM_LIST_MODEL (gtk_tree_view_get_model (tree_view)),
 		 tree_view,
 		 event->x, event->y);
-	
-	g_object_get (G_OBJECT (gtk_widget_get_settings (widget)), 
+
+	g_object_get (G_OBJECT (gtk_widget_get_settings (widget)),
 		      "gtk-double-click-time", &double_click_time,
 		      NULL);
 
@@ -991,13 +1002,13 @@ key_press_callback (GtkWidget *widget, GdkEventKey *event, gpointer callback_dat
 	handled = FALSE;
 
 	switch (event->keyval) {
-	case GDK_F10:
+	case GDK_KEY_F10:
 		if (event->state & GDK_CONTROL_MASK) {
 			fm_directory_view_pop_up_background_context_menu (view, &button_event);
 			handled = TRUE;
 		}
 		break;
-	case GDK_Right:
+	case GDK_KEY_Right:
 		gtk_tree_view_get_cursor (tree_view, &path, NULL);
 		if (path) {
 			gtk_tree_view_expand_row (tree_view, path, FALSE);
@@ -1005,7 +1016,7 @@ key_press_callback (GtkWidget *widget, GdkEventKey *event, gpointer callback_dat
 		}
 		handled = TRUE;
 		break;
-	case GDK_Left:
+	case GDK_KEY_Left:
 		gtk_tree_view_get_cursor (tree_view, &path, NULL);
 		if (path) {
 			gtk_tree_view_collapse_row (tree_view, path);
@@ -1013,7 +1024,7 @@ key_press_callback (GtkWidget *widget, GdkEventKey *event, gpointer callback_dat
 		}
 		handled = TRUE;
 		break;
-	case GDK_space:
+	case GDK_KEY_space:
 		if (event->state & GDK_CONTROL_MASK) {
 			handled = FALSE;
 			break;
@@ -1029,8 +1040,8 @@ key_press_callback (GtkWidget *widget, GdkEventKey *event, gpointer callback_dat
 		}
 		handled = TRUE;
 		break;
-	case GDK_Return:
-	case GDK_KP_Enter:
+	case GDK_KEY_Return:
+	case GDK_KEY_KP_Enter:
 		if ((event->state & GDK_SHIFT_MASK) != 0) {
 			activate_selected_items_alternate (FM_LIST_VIEW (view), NULL, TRUE);
 		} else {
@@ -1038,7 +1049,7 @@ key_press_callback (GtkWidget *widget, GdkEventKey *event, gpointer callback_dat
 		}
 		handled = TRUE;
 		break;
-	case GDK_v:
+	case GDK_KEY_v:
 		/* Eat Control + v to not enable type ahead */
 		if ((event->state & GDK_CONTROL_MASK) != 0) {
 			handled = TRUE;
@@ -1140,7 +1151,8 @@ sort_column_changed_callback (GtkTreeSortable *sortable,
 		 * or if it makes sense for the attribute (i.e. date). */
 		if (sort_attr == default_sort_attr) {
 			/* use value from preferences */
-			reversed = eel_preferences_get_boolean (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_SORT_IN_REVERSE_ORDER);
+			reversed = g_settings_get_boolean (nautilus_preferences,
+							   NAUTILUS_PREFERENCES_DEFAULT_SORT_IN_REVERSE_ORDER);
 		} else {
 			reversed = nautilus_file_is_date_sort_attribute_q (sort_attr);
 		}
@@ -1158,9 +1170,9 @@ sort_column_changed_callback (GtkTreeSortable *sortable,
 	reversed_attr = (reversed ? "true" : "false");
 	nautilus_file_set_metadata (file, NAUTILUS_METADATA_KEY_LIST_VIEW_SORT_REVERSED,
 				    default_reversed_attr, reversed_attr);
-				    
+
 	/* Make sure selected item(s) is visible after sort */
-	fm_list_view_reveal_selection (FM_DIRECTORY_VIEW (view));							      
+	fm_list_view_reveal_selection (FM_DIRECTORY_VIEW (view));
 
 	view->details->last_sort_attr = sort_attr;
 }
@@ -1490,7 +1502,7 @@ create_and_set_up_tree_view (FMListView *view)
 
 	/* Don't handle backspace key. It's used to open the parent folder. */
 	binding_set = gtk_binding_set_by_class (GTK_WIDGET_GET_CLASS (view->details->tree_view));
-	gtk_binding_entry_remove (binding_set, GDK_BackSpace, 0);
+	gtk_binding_entry_remove (binding_set, GDK_KEY_BackSpace, 0);
 
 	view->details->drag_dest = 
 		nautilus_tree_view_drag_dest_new (view->details->tree_view);
@@ -1586,7 +1598,7 @@ create_and_set_up_tree_view (FMListView *view)
 		 * has the icon in it.*/
 		if (!strcmp (name, "name")) {
 			/* Create the file name column */
-			cell = nautilus_cell_renderer_pixbuf_emblem_new ();
+			cell = gtk_cell_renderer_pixbuf_new ();
 			view->details->pixbuf_cell = (GtkCellRendererPixbuf *)cell;
 			
 			view->details->file_name_column = gtk_tree_view_column_new ();
@@ -1607,7 +1619,6 @@ create_and_set_up_tree_view (FMListView *view)
 			gtk_tree_view_column_set_attributes (view->details->file_name_column,
 							     cell,
 							     "pixbuf", FM_LIST_MODEL_SMALLEST_ICON_COLUMN,
-							     "pixbuf_emblem", FM_LIST_MODEL_SMALLEST_EMBLEM_COLUMN,
 							     NULL);
 			
 			cell = nautilus_cell_renderer_text_ellipsized_new ();
@@ -2524,7 +2535,7 @@ fm_list_view_set_zoom_level (FMListView *view,
 			     gboolean always_emit)
 {
 	int icon_size;
-	int column, emblem_column;
+	int column;
 
 	g_return_if_fail (FM_IS_LIST_VIEW (view));
 	g_return_if_fail (new_level >= NAUTILUS_ZOOM_LEVEL_SMALLEST &&
@@ -2548,11 +2559,9 @@ fm_list_view_set_zoom_level (FMListView *view,
 
 	/* Select correctly scaled icons. */
 	column = fm_list_model_get_column_id_from_zoom_level (new_level);
-	emblem_column = fm_list_model_get_emblem_column_id_from_zoom_level (new_level);
 	gtk_tree_view_column_set_attributes (view->details->file_name_column,
 					     GTK_CELL_RENDERER (view->details->pixbuf_cell),
 					     "pixbuf", column,
-					     "pixbuf_emblem", emblem_column,
 					     NULL);
 
 	/* Scale text. */
@@ -2861,6 +2870,19 @@ fm_list_view_finalize (GObject *object)
 
 	g_free (list_view->details);
 
+	g_signal_handlers_disconnect_by_func (nautilus_preferences,
+					      default_sort_order_changed_callback,
+					      list_view);
+	g_signal_handlers_disconnect_by_func (nautilus_list_view_preferences,
+					      default_zoom_level_changed_callback,
+					      list_view);
+	g_signal_handlers_disconnect_by_func (nautilus_list_view_preferences,
+					      default_visible_columns_changed_callback,
+					      list_view);
+	g_signal_handlers_disconnect_by_func (nautilus_list_view_preferences,
+					      default_column_order_changed_callback,
+					      list_view);
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -3045,18 +3067,24 @@ fm_list_view_class_init (FMListViewClass *class)
 	fm_directory_view_class->using_manual_layout = fm_list_view_using_manual_layout;
 	fm_directory_view_class->set_is_active = real_set_is_active;
 
-	eel_preferences_add_auto_enum (NAUTILUS_PREFERENCES_CLICK_POLICY,
-				       &click_policy_auto_value);
-	eel_preferences_add_auto_string (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_SORT_ORDER,
-					 (const char **) &default_sort_order_auto_value);
-	eel_preferences_add_auto_boolean (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_SORT_IN_REVERSE_ORDER,
-					  &default_sort_reversed_auto_value);
-	eel_preferences_add_auto_enum (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_ZOOM_LEVEL,
-				       (int *) &default_zoom_level_auto_value);
-	eel_preferences_add_auto_string_array (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_VISIBLE_COLUMNS,
-					       &default_visible_columns_auto_value);
-	eel_preferences_add_auto_string_array (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_COLUMN_ORDER,
-					       &default_column_order_auto_value);
+	eel_g_settings_add_auto_enum (nautilus_preferences,
+				      NAUTILUS_PREFERENCES_CLICK_POLICY,
+				      &click_policy_auto_value);
+	eel_g_settings_add_auto_enum (nautilus_preferences,
+				      NAUTILUS_PREFERENCES_DEFAULT_SORT_ORDER,
+				      (int *) &default_sort_order_auto_value);
+	eel_g_settings_add_auto_boolean (nautilus_preferences,
+					 NAUTILUS_PREFERENCES_DEFAULT_SORT_IN_REVERSE_ORDER,
+					 &default_sort_reversed_auto_value);
+	eel_g_settings_add_auto_enum (nautilus_list_view_preferences,
+				      NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_ZOOM_LEVEL,
+				      (int *) &default_zoom_level_auto_value);
+	eel_g_settings_add_auto_strv (nautilus_list_view_preferences,
+				      NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_VISIBLE_COLUMNS,
+				      &default_visible_columns_auto_value);
+	eel_g_settings_add_auto_strv (nautilus_list_view_preferences,
+				      NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_COLUMN_ORDER,
+				      &default_column_order_auto_value);
 }
 
 static const char *
@@ -3070,7 +3098,7 @@ static void
 fm_list_view_iface_init (NautilusViewIface *iface)
 {
 	fm_directory_view_init_view_iface (iface);
-	
+
 	iface->get_view_id = fm_list_view_get_id;
 	iface->get_first_visible_file = fm_list_view_get_first_visible_file;
 	iface->scroll_to_file = list_view_scroll_to_file;
@@ -3085,31 +3113,36 @@ fm_list_view_init (FMListView *list_view)
 
 	create_and_set_up_tree_view (list_view);
 
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_SORT_ORDER,
-						  default_sort_order_changed_callback,
-						  list_view, G_OBJECT (list_view));
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_SORT_IN_REVERSE_ORDER,
-						  default_sort_order_changed_callback,
-						  list_view, G_OBJECT (list_view));
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_ZOOM_LEVEL,
-						  default_zoom_level_changed_callback,
-						  list_view, G_OBJECT (list_view));
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_VISIBLE_COLUMNS,
-						  default_visible_columns_changed_callback,
-						  list_view, G_OBJECT (list_view));
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_COLUMN_ORDER,
-						  default_column_order_changed_callback,
-						  list_view, G_OBJECT (list_view));
+	g_signal_connect_swapped (nautilus_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_DEFAULT_SORT_ORDER,
+				  G_CALLBACK (default_sort_order_changed_callback),
+				  list_view);
+	g_signal_connect_swapped (nautilus_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_DEFAULT_SORT_IN_REVERSE_ORDER,
+				  G_CALLBACK (default_sort_order_changed_callback),
+				  list_view);
+	g_signal_connect_swapped (nautilus_list_view_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_ZOOM_LEVEL,
+				  G_CALLBACK (default_zoom_level_changed_callback),
+				  list_view);
+	g_signal_connect_swapped (nautilus_list_view_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_VISIBLE_COLUMNS,
+				  G_CALLBACK (default_visible_columns_changed_callback),
+				  list_view);
+	g_signal_connect_swapped (nautilus_list_view_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_COLUMN_ORDER,
+				  G_CALLBACK (default_column_order_changed_callback),
+				  list_view);
 
 	fm_list_view_click_policy_changed (FM_DIRECTORY_VIEW (list_view));
-	
+
 	fm_list_view_sort_directories_first_changed (FM_DIRECTORY_VIEW (list_view));
-	
+
 	/* ensure that the zoom level is always set in begin_loading */
 	list_view->details->zoom_level = NAUTILUS_ZOOM_LEVEL_SMALLEST - 1;
 
 	list_view->details->hover_path = NULL;
-	list_view->details->clipboard_handler_id = 
+	list_view->details->clipboard_handler_id =
 		g_signal_connect (nautilus_clipboard_monitor_get (),
 		                  "clipboard_info",
 		                  G_CALLBACK (list_view_notify_clipboard_info), list_view);
