@@ -35,7 +35,6 @@
 #include <libnautilus-private/nautilus-window-info.h>
 #include <libnautilus-private/nautilus-search-directory.h>
 #include "nautilus-application.h"
-#include "nautilus-information-panel.h"
 #include "nautilus-side-pane.h"
 
 #define NAUTILUS_TYPE_WINDOW nautilus_window_get_type()
@@ -119,7 +118,6 @@ struct NautilusWindow {
         
         NautilusWindowDetails *details;
         
-        /** CORBA-related elements **/
         NautilusApplication *application;
 };
 
@@ -134,16 +132,20 @@ void             nautilus_window_disconnect_content_view (NautilusWindow    *win
 
 void             nautilus_window_go_to                (NautilusWindow    *window,
                                                        GFile             *location);
+void             nautilus_window_go_to_full           (NautilusWindow    *window,
+                                                       GFile             *location,
+                                                       NautilusWindowGoToCallback callback,
+                                                       gpointer           user_data);
 void             nautilus_window_go_to_with_selection (NautilusWindow    *window,
                                                        GFile             *location,
                                                        GList             *new_selection);
 void             nautilus_window_go_home              (NautilusWindow    *window);
+void             nautilus_window_new_tab              (NautilusWindow    *window);
 void             nautilus_window_go_up                (NautilusWindow    *window,
                                                        gboolean           close_behind,
 						       gboolean           new_tab);
 void             nautilus_window_prompt_for_location  (NautilusWindow    *window,
                                                        const char        *initial);
-void             nautilus_window_launch_cd_burner     (NautilusWindow    *window);
 void             nautilus_window_display_error        (NautilusWindow    *window,
                                                        const char        *error_msg);
 void		 nautilus_window_reload		      (NautilusWindow	 *window);
@@ -154,9 +156,6 @@ void             nautilus_window_allow_up             (NautilusWindow    *window
                                                        gboolean           allow);
 void             nautilus_window_allow_stop           (NautilusWindow    *window, 
                                                        gboolean           allow);
-void             nautilus_window_allow_burn_cd        (NautilusWindow    *window,
-                                                       gboolean           allow);
 GtkUIManager *   nautilus_window_get_ui_manager       (NautilusWindow    *window);
-gboolean         nautilus_window_has_menubar_and_statusbar (NautilusWindow *window);
 
 #endif
